@@ -43,7 +43,7 @@ retrieve <- function(id, dir = content_dir()) {
     
     if (!file.exists(path)) {
       warning(paste("No stored file found for", id, "in", dir), call. = FALSE)
-      return(NULL)
+      return(NA_character_)
     }
     
     ## We could call `file(path)` instead, but would make assumptions about how
@@ -53,10 +53,15 @@ retrieve <- function(id, dir = content_dir()) {
 }
 
 
-store_list <- function(dir = content_dir()){
-  fs::dir_info(path = fs::path(dir, "data"), recurse = TRUE, type = "file")
+
+# function not in use...
+store_list <- function(dir = content_dir(), algos = default_algos()){
+  # include symlinks? 
+  fs::dir_info(path = fs::path(dir, algos), recurse = TRUE, type = "file")
 }
 
+
+
 store_delete <- function(ids, dir = content_dir()){
   lapply(ids, function(id){ 
     path <- content_based_location(id, dir)
