@@ -5,9 +5,7 @@ test_that("We can register & retrieve content from the remote API", {
   skip_on_cran()
 
   ## A zenodo URL will be stable
-  url <- "https://zenodo.org/record/3678928/files/vostok.icecore.co2"
-  ## or not.... use KNB
-  url <- "https://knb.ecoinformatics.org/knb/d1/mn/v2/object/ess-dive-457358fdc81d3a5-20180726T203952542"
+  url <- "https://zenodo.org/api/files/5967f986-b599-4492-9a08-94ce32323dc2/vostok.icecore.co2"
   
   ## hash-archive.org may timeout more often these days...
   hash_archive <- "https://hash-archive.org"
